@@ -22,8 +22,14 @@ class SilaClient:
     _children_by_fully_qualified_identifier: Dict[FullyQualifiedIdentifier, HasFullyQualifiedIdentifier]
     _registered_defined_execution_error_classes: Dict[FullyQualifiedIdentifier, Type[DefinedExecutionError]]
 
-    def __init__(self, hostname: str, port: int):
-        self._channel = grpc.insecure_channel(f"{hostname}:{port}")
+    __address: str
+    __port: int
+
+    def __init__(self, address: str, port: int):
+        self.__address = address
+        self.__port = port
+
+        self._channel = grpc.insecure_channel(f"{self.__address}:{self.__port}")
         self._features = {}
         self._children_by_fully_qualified_identifier = {}
         self._registered_defined_execution_error_classes = {}
@@ -53,3 +59,11 @@ class SilaClient:
         self, error_node: DefinedExecutionErrorNode, error_class: Type[DefinedExecutionError]
     ):
         self._registered_defined_execution_error_classes[error_node.fully_qualified_identifier] = error_class
+
+    @property
+    def address(self):
+        return self.__address
+
+    @property
+    def port(self):
+        return self.__port
