@@ -4,6 +4,7 @@ import logging
 import re
 from collections import defaultdict
 from contextlib import contextmanager
+from queue import Queue
 from typing import TYPE_CHECKING, Any, Callable, Dict, Iterable, Iterator, List, NoReturn, Optional, Set, Tuple, Union
 from uuid import UUID
 
@@ -26,6 +27,7 @@ from sila2.framework.defined_execution_error_node import DefinedExecutionErrorNo
 from sila2.framework.errors.invalid_command_execution_uuid import InvalidCommandExecutionUUID
 from sila2.framework.feature import Feature
 from sila2.framework.fully_qualified_identifier import FullyQualifiedIdentifier
+from sila2.framework.property.observable_property import ObservableProperty
 from sila2.framework.utils import FullyQualifiedIdentifierRegex, raise_as_rpc_error
 from sila2.server.feature_implementation_base import FeatureImplementationBase
 from sila2.server.observables.observable_command_manager import ObservableCommandManager
@@ -42,7 +44,7 @@ class FeatureImplementationServicer:
     feature: Feature
     implementation: Optional[FeatureImplementationBase]
     observable_command_managers: Dict[str, Dict[UUID, ObservableCommandManager]]
-    observable_property_subscription_managers: Dict[str, SubscriptionManagerThread]
+    observable_property_subscription_managers: Dict[str, Dict[Optional[Queue], SubscriptionManagerThread]]
 
     def __init__(self, parent_server: SilaServer, feature: Feature):
         self.parent_server = parent_server
@@ -89,7 +91,7 @@ class FeatureImplementationServicer:
                 getattr(self.implementation, f"_{prop._identifier}_producer_queue"),
                 prop.to_message,
             )
-            self.observable_property_subscription_managers[prop._identifier] = manager
+            self.observable_property_subscription_managers[prop._identifier] = {None: manager}
             manager.start()
 
     def __get_observable_command_manager(
@@ -218,7 +220,6 @@ class FeatureImplementationServicer:
         self, property_id: str
     ) -> Callable[[Message, ServicerContext], Iterator[Message]]:
         prop = self.feature._observable_properties[property_id]
-        manager = self.observable_property_subscription_managers[property_id]
         impl_func = getattr(self.implementation, f"{property_id}_on_subscription")
 
         def wrapper(request: Message, context: ServicerContext) -> Iterator[Message]:
@@ -229,7 +230,8 @@ class FeatureImplementationServicer:
             with raises_rpc_errors(context, self.logger, allowed_errors):
                 self.__apply_metadata_interceptors(None, metadata, prop.fully_qualified_identifier)
 
-                impl_func(metadata=metadata)
+                queue = impl_func(metadata=metadata)
+                manager = self.__get_observable_property_subscription_thread_for_queue(prop, queue)
 
                 for value in manager.add_subscription():
                     yield value
@@ -251,8 +253,9 @@ class FeatureImplementationServicer:
 
     def cancel_all_subscriptions(self):
         self.logger.info("Cancelling all subscriptions")
-        for manager in self.observable_property_subscription_managers.values():
-            manager.cancel_producer()
+        for managers in self.observable_property_subscription_managers.values():
+            for manager in managers.values():
+                manager.cancel_producer()
 
     def __apply_metadata_interceptors(
         self, parameters: Any, metadata: Dict[FullyQualifiedIdentifier, Any], target: FullyQualifiedIdentifier
@@ -352,6 +355,25 @@ class FeatureImplementationServicer:
         self.logger.error(f"Raising as RpcError {error!r}")
         raise_as_rpc_error(error, context)
 
+    def __get_observable_property_subscription_thread_for_queue(
+        self, prop: ObservableProperty, queue: Optional[Queue]
+    ) -> SubscriptionManagerThread:
+        prop_managers = self.observable_property_subscription_managers[prop._identifier]
+
+        # default queue
+        if queue is None:
+            return prop_managers[None]
+
+        # subscribe to existing custom queue
+        if queue in prop_managers:
+            return prop_managers[queue]
+
+        # new custom queue
+        manager = SubscriptionManagerThread(prop.fully_qualified_identifier, queue, prop.to_message)
+        prop_managers[queue] = manager
+        manager.start()
+        return manager
+
 
 @contextmanager
 def raises_rpc_errors(
